@@ -9,20 +9,20 @@
 # lost the next time ruby is built.
 
 module RbConfig
-  RUBY_VERSION.start_with?("3.3.") or
-    raise "ruby lib version (3.3.7) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION.start_with?("3.4.") or
+    raise "ruby lib version (3.4.1) doesn't match executable version (#{RUBY_VERSION})"
 
   # Ruby installed directory.
-  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/3.3.0/x86_64-cygwin")
+  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/3.4.0/x86_64-cygwin")
   # DESTDIR on make install.
   DESTDIR = '' unless defined? DESTDIR
   # The hash configurations stored.
   CONFIG = {}
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "3"
-  CONFIG["MINOR"] = "3"
-  CONFIG["TEENY"] = "7"
-  CONFIG["PATCHLEVEL"] = "123"
+  CONFIG["MINOR"] = "4"
+  CONFIG["TEENY"] = "1"
+  CONFIG["PATCHLEVEL"] = "0"
   CONFIG["INSTALL"] = '/usr/bin/install -c'
   CONFIG["EXEEXT"] = ".exe"
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr")
@@ -30,7 +30,7 @@ module RbConfig
   CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)"
   CONFIG["RUBY_SO_NAME"] = "$(RUBY_BASE_NAME)$(MAJOR)$(MINOR)0"
   CONFIG["exec"] = "exec"
-  CONFIG["ruby_pc"] = "ruby-3.3.pc"
+  CONFIG["ruby_pc"] = "ruby-3.4.pc"
   CONFIG["CC_WRAPPER"] = ""
   CONFIG["PACKAGE"] = "ruby"
   CONFIG["BUILTIN_TRANSSRCS"] = " enc/trans/newline.c"
@@ -55,7 +55,7 @@ module RbConfig
   CONFIG["sitedir"] = "$(rubylibprefix)/site_ruby"
   CONFIG["rubyarchdir"] = "$(rubylibdir)/$(arch)"
   CONFIG["rubylibdir"] = "$(rubylibprefix)/$(ruby_version)"
-  CONFIG["ruby_version"] = "3.3.0"
+  CONFIG["ruby_version"] = "3.4.0"
   CONFIG["sitearch"] = "$(arch)"
   CONFIG["arch"] = "x86_64-cygwin"
   CONFIG["sitearchincludedir"] = "$(includedir)/$(sitearch)"
@@ -97,6 +97,7 @@ module RbConfig
   CONFIG["rubyw_install_name"] = ""
   CONFIG["EXTDLDFLAGS"] = ""
   CONFIG["EXTLDFLAGS"] = ""
+  CONFIG["hardenflags"] = "-fstack-protector-strong -U_FORTIFY_SOURCE -D_FORTIFY_SOURCE=2"
   CONFIG["strict_warnflags"] = ""
   CONFIG["warnflags"] = "-Wall -Wextra -Wdeprecated-declarations -Wdiv-by-zero -Wduplicated-cond -Wimplicit-function-declaration -Wimplicit-int -Wpointer-arith -Wwrite-strings -Wold-style-definition -Wimplicit-fallthrough=0 -Wmissing-noreturn -Wno-cast-function-type -Wno-constant-logical-operand -Wno-long-long -Wno-missing-field-initializers -Wno-overlength-strings -Wno-packed-bitfield-compat -Wno-parentheses-equality -Wno-self-assign -Wno-tautological-compare -Wno-unused-parameter -Wno-unused-value -Wsuggest-attribute=format -Wsuggest-attribute=noreturn -Wunused-variable -Wmisleading-indentation -Wundef"
   CONFIG["debugflags"] = "-ggdb3"
@@ -112,6 +113,7 @@ module RbConfig
   CONFIG["CARGO"] = ""
   CONFIG["RUSTC"] = "no"
   CONFIG["INSTALL_STATIC_LIBRARY"] = "no"
+  CONFIG["modular_gc_dir"] = ""
   CONFIG["EXECUTABLE_EXTS"] = ".exe .com .cmd .bat"
   CONFIG["ARCHFILE"] = ""
   CONFIG["LIBRUBY_RELATIVE"] = "no"
@@ -126,8 +128,8 @@ module RbConfig
   CONFIG["PRELOADENV"] = ""
   CONFIG["LIBPATHENV"] = "PATH"
   CONFIG["RPATHFLAG"] = ""
-  CONFIG["LIBPATHFLAG"] = " -L%s"
-  CONFIG["LINK_SO"] = ""
+  CONFIG["LIBPATHFLAG"] = "-L%s"
+  CONFIG["LINK_SO"] = "\n$(POSTLINK)"
   CONFIG["ADDITIONAL_DLDFLAGS"] = ""
   CONFIG["ENCSTATIC"] = ""
   CONFIG["EXTSTATIC"] = ""
@@ -167,7 +169,6 @@ module RbConfig
   CONFIG["LN_S"] = "cp -pR"
   CONFIG["DLLWRAP"] = "dllwrap"
   CONFIG["WINDRES"] = "windres"
-  CONFIG["ASFLAGS"] = ""
   CONFIG["ARFLAGS"] = "rcD "
   CONFIG["try_header"] = ""
   CONFIG["CC_VERSION_MESSAGE"] = "gcc (GCC) 13.3.0\nCopyright (C) 2023 Free Software Foundation, Inc.\nThis is free software; see the source for copying conditions.  There is NO\nwarranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."
@@ -196,6 +197,7 @@ module RbConfig
   CONFIG["CC"] = "gcc"
   CONFIG["wasmoptflags"] = ""
   CONFIG["WASMOPT"] = ""
+  CONFIG["config_target"] = "x86_64-pc-cygwin"
   CONFIG["target_os"] = "cygwin"
   CONFIG["target_vendor"] = "pc"
   CONFIG["target_cpu"] = "x86_64"
@@ -217,7 +219,7 @@ module RbConfig
   CONFIG["GIT"] = "git"
   CONFIG["cxxflags"] = ""
   CONFIG["cppflags"] = ""
-  CONFIG["cflags"] = "$(optflags) $(debugflags) $(warnflags)"
+  CONFIG["cflags"] = "$(hardenflags)  $(optflags) $(debugflags) $(warnflags)"
   CONFIG["MAKEDIRS"] = "/usr/bin/mkdir -p"
   CONFIG["target_alias"] = ""
   CONFIG["host_alias"] = "$(target_alias)"
